import { AppNotification } from "../model/AppNotification";
import { Channel } from "./Channel";
import { ElectronUtils } from "../utils/ElectronUtils";
export class NotificationApi {
    // static async url(url: string, duration: number = -1) {
    //     ElectronUtils.getAPI()?.invoke(Channel.NOTIFICATION, new AppNotification({
    //         url, message: "",
    //         duration,
    //         type: "url",
    //     }));
    // }
    /**
     * 来电
     * @param avatar    头像地址
     * @param audio     音频地址
     * @param title     标题文件
     * @param message   初始消息
     * @param lyric     歌词字符串
     */
    static async call(avatar, audio, title, message, lyric) {
        var _a;
        (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, new AppNotification({
            avatar,
            audio,
            message,
            title,
            duration: -1,
            lyric,
            type: "call",
        }));
    }
    static async send(notification) {
        var _a;
        return (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, notification);
    }
    static async reminder(title, message, icon, cancelButtonText, confirmButtonText, cancelBroadcast, confirmBroadcast, duration = 5000) {
        return await this.send(new AppNotification({
            icon,
            message,
            title,
            duration,
            cancelButtonText,
            confirmButtonText,
            cancelBroadcast,
            confirmBroadcast,
            type: "reminder",
        }));
    }
    static async advanceCountdown(message, targetTime, title) {
        return await this.send(new AppNotification({
            title,
            message,
            targetTime,
            type: "advance-countdown"
        }));
    }
    static async countdown(message, targetTime) {
        var _a;
        (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, new AppNotification({
            message,
            targetTime,
            backgroundColor: 'rgba(0,0,0,0.5)',
            duration: -1,
            type: "countdown"
        }));
    }
    static async success(message, duration = 5000) {
        var _a;
        if (ElectronUtils.hasElectronApi()) {
            (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, new AppNotification({
                message,
                type: "success",
                icon: "check_circle_line",
                duration
            }));
        }
        else {
            this.callback("success", message, duration);
        }
    }
    static async error(message, duration = 5000) {
        var _a;
        if (ElectronUtils.hasElectronApi()) {
            (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, new AppNotification({
                message,
                type: "error",
                icon: "close_circle_line",
                duration
            }));
        }
        else {
            this.callback("error", message, duration);
        }
    }
    static async warning(message, duration = 5000) {
        var _a;
        if (ElectronUtils.hasElectronApi()) {
            (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, new AppNotification({
                message,
                type: "warning",
                icon: "warning_line",
                duration
            }));
        }
        else {
            this.callback("warning", message, duration);
        }
    }
    static async info(message, duration = 5000) {
        var _a;
        if (ElectronUtils.hasElectronApi()) {
            (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, new AppNotification({
                message,
                type: "info",
                icon: "information_line",
                duration
            }));
        }
        else {
            this.callback("info", message, duration);
        }
    }
    /**
     * 隐藏通知
     */
    static async hide() {
        var _a;
        if (ElectronUtils.hasElectronApi()) {
            (_a = ElectronUtils.getAPI()) === null || _a === void 0 ? void 0 : _a.invoke(Channel.NOTIFICATION, null);
        }
    }
    static setDebugNotification(callback) {
        this.callback = callback;
    }
}
