import { Widget } from "../model/Widget";
import { WidgetPackage } from "../model/WidgetPackage";
import { WidgetParams } from "../model/WidgetParams";
import { WidgetData } from "../model/WidgetData";
import HostedWidget from "../model/HostedWidget";
export interface SaveWidgetOption {
    sendBroadcast?: boolean;
    id?: string;
}
export declare class WidgetApi {
    static readonly REGISTER_WIDGETS = "register-widgets";
    static readonly REGISTER_WIDGET_PACKAGE = "register-widget-package";
    static readonly GET_WIDGETS = "get-widgets";
    static readonly GET_WIDGET = "get-widget";
    static readonly GET_WIDGET_PACKAGE = "get-widget-package";
    static readonly GET_WIDGET_PACKAGES = "get-widget-packages";
    static readonly REMOVE_HOSTED_WIDGET = "remove-hosted-widget";
    static readonly REMOVE_HOSTED_WIDGET_BY_NAME = "remove-hosted-widget-by-name";
    static readonly GET_HOSTED_WIDGETS = "get-hosted-widgets";
    static readonly OPEN_DEV_TOOLS = "open-dev-tools";
    static registerWidgets(widgets: Widget[]): Promise<void>;
    static registerWidgetPackage(widgetPackage: WidgetPackage): Promise<void>;
    static getWidgets(): Promise<Widget[]>;
    static getWidgetPackages(): Promise<WidgetPackage>;
    /**
     *
     * @param name package name
     */
    static getWidget(name: string): Promise<Widget>;
    /**
     *
     * @param name package name
     */
    static getWidgetPackage(name: string): Promise<WidgetPackage>;
    /**
     * 移除组件
     * @param id
     */
    static removeHostedWidget(id: string): Promise<any>;
    /**
     * 通过组件名移除已添加的组件
     * @param name  组件名
     */
    static removeHostedWidgetByName(name: string): Promise<HostedWidget[]>;
    /**
     * 获取已添加的组件
     * @param name  组件名，可以不传
     */
    static getHostedWidgets(name?: string): Promise<HostedWidget[]>;
    static openDevTools(widgetId: string): Promise<any>;
    /**
     * 获取组件配置地址
     * @param widgetName
     */
    static getWidgetConfigUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    static getWidgetUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    static getWidgetPackageIndexUrl(packageName: string, hash?: boolean): Promise<string | null>;
    static getWidgetPackageUrl(packageName: string): Promise<string | null>;
    /**
     * 通过组件名保存组件信息，通常用于存储可以在同类组件中共用的数据
     * @param data
     * @param options
     */
    static saveDataByName<T extends WidgetData>(data: T, options?: SaveWidgetOption): Promise<string>;
    private static stores;
    /**
     * 获取组件 LocalForage 存储实例
     * @param name
     */
    static getStore(name: string): LocalForage;
}
